#
# db2_profile::database::db_primary
#
# @summary When the property `db2_profile::database::primary` is set, and the current node is the designated primary server, this class will be applied.
# It will set the database in archiving mode, create a backup and then set the database in primary mode.
#
# @param [String[1]] instance
#    The instance to use for the database.
#
# @param [String[1]] database
#    The database name to use for the primary or standby database.
#    this needs to be the same on the primary and standby nodes.
#
# @param [Stdlib::Absolutepath] archive_path
#    The path to use for DB2 archiving.
#
# @param [Stdlib::Absolutepath] backup_path
#    The location to put the DB2 database backup.
#
# @param [String[1]] owner
#    The owner to use for the archive and backup directories.
#
# @param [String[1]] group
#    The group to use for the archive and backup directories.
#
# @param [Integer] wait_time
#    The in seconds to wait to set he database in primary mode aftercthe backup has been made.
#
# @param [Variant[Boolean, Enum['on_failure']]] logoutput
#    If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
#    The default is `on_failure`.
#    Here is an example on how to use this:
#        class { '::db2_install::...':
#          ...
#          logoutput => true,
#          ...
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
class db2_profile::database::db_primary (
  Stdlib::Absolutepath $archive_path,
  Stdlib::Absolutepath $backup_path,
  String[1]            $database,
  String[1]            $group,
  String[1]            $instance,
  String[1]            $owner,
  Integer              $wait_time,
  Variant[Boolean,Enum['on_failure']]
  $logoutput = lookup({ name => 'logoutput', default_value => 'on_failure' })
) {
  easy_type::debug_evaluation() # Show local variable on extended debug

  echo { "Ensure DB2 archiving path '${$archive_path}'":
    withpath => false,
  }
  file { [$archive_path, $backup_path]:
    ensure => 'directory',
    owner  => $owner,
    group  => $group,
  }

  if $facts['db2_databases'].dig("${instance}/${database}") == undef {
    exec { "Set database ${database} in archiving mode":
      command     => "/home/${instance}/sqllib/bin/db2 update db cfg for ${database} using LOGARCHMETH1 \"DISK:${archive_path}\"",
      unless      => "/home/${instance}/sqllib/bin/db2 get database config for ${database} | /usr/bin/grep \"(LOGARCHMETH1) = DISK:${archive_path}\"",
      user        => $instance,
      environment => "DB2INSTANCE=${instance}",
      logoutput   => $logoutput,
    }

    -> exec { "create backup for ${database}":
      command     => "/bin/sleep ${wait_time};/home/${instance}/sqllib/bin/db2 backup database ${database} to ${backup_path}",
      cwd         => $backup_path,
      user        => $instance,
      environment => "DB2INSTANCE=${instance}",
      logoutput   => $logoutput,
    }

    -> exec { "set database '${database}' as primary":
      command     => "/home/${instance}/sqllib/bin/db2 start hadr on database ${database} as primary by force",
      user        => $instance,
      environment => "DB2INSTANCE=${instance}",
      logoutput   => $logoutput,
    }
  }
}
