#
# db2_profile::database::passwordless_root
#
# @summary The class enables passwordless root access between the nodes in the cluster.
# It will enable ssh access for the root account based on the specified private and public keys.
# 
# For this to work, **all** of the nodes must be reachable on the network before this class is applied.
#
# @param [Array[String[1]]] nodes
#    An array of nodes you want to enable passwordless root access between.
#
# @param [String[1]] private_key
#    
#
# @param [String[1]] public_key
#    The public key to use to enable passwordless access between the nodes in the cluster.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class db2_profile::database::passwordless_root (
  Array[String[1]] $nodes,
  String[1]        $private_key,
  String[1]        $public_key
) {
  easy_type::debug_evaluation() # Show local variable on extended debug

  unless defined(Package['openssh-clients']) {
    package { 'openssh-clients':
      ensure => 'present',
    }
  }

  file { '/root/.ssh':
    ensure => 'directory',
    mode   => '0700',
    owner  => 'root',
  }

  -> file { '/root/.ssh/id_rsa':
    ensure  => 'file',
    content => $private_key,
    mode    => '0700',
    owner   => 'root',
  }

  $nodes.each |$node_name| {
    exec { "authorize_node_${node_name}_for_root":
      user    => 'root',
      command => "/usr/bin/ssh-keyscan ${node_name} >> ~/.ssh/known_hosts",
      unless  => "/bin/grep ${node_name} /root/.ssh/known_hosts",
      returns => [0,1],
      require => [
        File['/root/.ssh/id_rsa'],
        Package['openssh-clients'],
      ],
    }
  }

  ssh_authorized_key { 'root':
    ensure => present,
    user   => 'root',
    type   => 'ssh-rsa',
    key    => $public_key,
  }
}
